@@ -2,7 +2,7 @@ from setuptools import setup, find_packages
 
 setup(
     name='capisce',
-    version='0.0.3',
+    version='0.0.5',
     packages=find_packages(),
     install_requires=[
         'requests',
@@ -10,7 +10,5 @@ setup(
         'ratelimit',
         'flask_cors'
     ],
-    entry_points={
-        'console_scripts': ['capisce=capisce.capisce:__main__'],
-    }
+    scripts=['capisce/capisce.py']
 )
